/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

package com.liferay.friendly.url.service.persistence;

import aQute.bnd.annotation.ProviderType;

import com.liferay.friendly.url.exception.NoSuchFriendlyURLEntryMappingException;
import com.liferay.friendly.url.model.FriendlyURLEntryMapping;

import com.liferay.portal.kernel.service.persistence.BasePersistence;

/**
 * The persistence interface for the friendly url entry mapping service.
 *
 * <p>
 * Caching information and settings can be found in <code>portal.properties</code>
 * </p>
 *
 * @author Brian Wing Shun Chan
 * @see com.liferay.friendly.url.service.persistence.impl.FriendlyURLEntryMappingPersistenceImpl
 * @see FriendlyURLEntryMappingUtil
 * @generated
 */
@ProviderType
public interface FriendlyURLEntryMappingPersistence extends BasePersistence<FriendlyURLEntryMapping> {
	/*
	 * NOTE FOR DEVELOPERS:
	 *
	 * Never modify or reference this interface directly. Always use {@link FriendlyURLEntryMappingUtil} to access the friendly url entry mapping persistence. Modify <code>service.xml</code> and rerun ServiceBuilder to regenerate this interface.
	 */

	/**
	* Returns the friendly url entry mapping where classNameId = &#63; and classPK = &#63; or throws a {@link NoSuchFriendlyURLEntryMappingException} if it could not be found.
	*
	* @param classNameId the class name ID
	* @param classPK the class pk
	* @return the matching friendly url entry mapping
	* @throws NoSuchFriendlyURLEntryMappingException if a matching friendly url entry mapping could not be found
	*/
	public FriendlyURLEntryMapping findByC_C(long classNameId, long classPK)
		throws NoSuchFriendlyURLEntryMappingException;

	/**
	* Returns the friendly url entry mapping where classNameId = &#63; and classPK = &#63; or returns <code>null</code> if it could not be found. Uses the finder cache.
	*
	* @param classNameId the class name ID
	* @param classPK the class pk
	* @return the matching friendly url entry mapping, or <code>null</code> if a matching friendly url entry mapping could not be found
	*/
	public FriendlyURLEntryMapping fetchByC_C(long classNameId, long classPK);

	/**
	* Returns the friendly url entry mapping where classNameId = &#63; and classPK = &#63; or returns <code>null</code> if it could not be found, optionally using the finder cache.
	*
	* @param classNameId the class name ID
	* @param classPK the class pk
	* @param retrieveFromCache whether to retrieve from the finder cache
	* @return the matching friendly url entry mapping, or <code>null</code> if a matching friendly url entry mapping could not be found
	*/
	public FriendlyURLEntryMapping fetchByC_C(long classNameId, long classPK,
		boolean retrieveFromCache);

	/**
	* Removes the friendly url entry mapping where classNameId = &#63; and classPK = &#63; from the database.
	*
	* @param classNameId the class name ID
	* @param classPK the class pk
	* @return the friendly url entry mapping that was removed
	*/
	public FriendlyURLEntryMapping removeByC_C(long classNameId, long classPK)
		throws NoSuchFriendlyURLEntryMappingException;

	/**
	* Returns the number of friendly url entry mappings where classNameId = &#63; and classPK = &#63;.
	*
	* @param classNameId the class name ID
	* @param classPK the class pk
	* @return the number of matching friendly url entry mappings
	*/
	public int countByC_C(long classNameId, long classPK);

	/**
	* Caches the friendly url entry mapping in the entity cache if it is enabled.
	*
	* @param friendlyURLEntryMapping the friendly url entry mapping
	*/
	public void cacheResult(FriendlyURLEntryMapping friendlyURLEntryMapping);

	/**
	* Caches the friendly url entry mappings in the entity cache if it is enabled.
	*
	* @param friendlyURLEntryMappings the friendly url entry mappings
	*/
	public void cacheResult(
		java.util.List<FriendlyURLEntryMapping> friendlyURLEntryMappings);

	/**
	* Creates a new friendly url entry mapping with the primary key. Does not add the friendly url entry mapping to the database.
	*
	* @param friendlyURLEntryMappingId the primary key for the new friendly url entry mapping
	* @return the new friendly url entry mapping
	*/
	public FriendlyURLEntryMapping create(long friendlyURLEntryMappingId);

	/**
	* Removes the friendly url entry mapping with the primary key from the database. Also notifies the appropriate model listeners.
	*
	* @param friendlyURLEntryMappingId the primary key of the friendly url entry mapping
	* @return the friendly url entry mapping that was removed
	* @throws NoSuchFriendlyURLEntryMappingException if a friendly url entry mapping with the primary key could not be found
	*/
	public FriendlyURLEntryMapping remove(long friendlyURLEntryMappingId)
		throws NoSuchFriendlyURLEntryMappingException;

	public FriendlyURLEntryMapping updateImpl(
		FriendlyURLEntryMapping friendlyURLEntryMapping);

	/**
	* Returns the friendly url entry mapping with the primary key or throws a {@link NoSuchFriendlyURLEntryMappingException} if it could not be found.
	*
	* @param friendlyURLEntryMappingId the primary key of the friendly url entry mapping
	* @return the friendly url entry mapping
	* @throws NoSuchFriendlyURLEntryMappingException if a friendly url entry mapping with the primary key could not be found
	*/
	public FriendlyURLEntryMapping findByPrimaryKey(
		long friendlyURLEntryMappingId)
		throws NoSuchFriendlyURLEntryMappingException;

	/**
	* Returns the friendly url entry mapping with the primary key or returns <code>null</code> if it could not be found.
	*
	* @param friendlyURLEntryMappingId the primary key of the friendly url entry mapping
	* @return the friendly url entry mapping, or <code>null</code> if a friendly url entry mapping with the primary key could not be found
	*/
	public FriendlyURLEntryMapping fetchByPrimaryKey(
		long friendlyURLEntryMappingId);

	@Override
	public java.util.Map<java.io.Serializable, FriendlyURLEntryMapping> fetchByPrimaryKeys(
		java.util.Set<java.io.Serializable> primaryKeys);

	/**
	* Returns all the friendly url entry mappings.
	*
	* @return the friendly url entry mappings
	*/
	public java.util.List<FriendlyURLEntryMapping> findAll();

	/**
	* Returns a range of all the friendly url entry mappings.
	*
	* <p>
	* Useful when paginating results. Returns a maximum of <code>end - start</code> instances. <code>start</code> and <code>end</code> are not primary keys, they are indexes in the result set. Thus, <code>0</code> refers to the first result in the set. Setting both <code>start</code> and <code>end</code> to {@link QueryUtil#ALL_POS} will return the full result set. If <code>orderByComparator</code> is specified, then the query will include the given ORDER BY logic. If <code>orderByComparator</code> is absent and pagination is required (<code>start</code> and <code>end</code> are not {@link QueryUtil#ALL_POS}), then the query will include the default ORDER BY logic from {@link FriendlyURLEntryMappingModelImpl}. If both <code>orderByComparator</code> and pagination are absent, for performance reasons, the query will not have an ORDER BY clause and the returned result set will be sorted on by the primary key in an ascending order.
	* </p>
	*
	* @param start the lower bound of the range of friendly url entry mappings
	* @param end the upper bound of the range of friendly url entry mappings (not inclusive)
	* @return the range of friendly url entry mappings
	*/
	public java.util.List<FriendlyURLEntryMapping> findAll(int start, int end);

	/**
	* Returns an ordered range of all the friendly url entry mappings.
	*
	* <p>
	* Useful when paginating results. Returns a maximum of <code>end - start</code> instances. <code>start</code> and <code>end</code> are not primary keys, they are indexes in the result set. Thus, <code>0</code> refers to the first result in the set. Setting both <code>start</code> and <code>end</code> to {@link QueryUtil#ALL_POS} will return the full result set. If <code>orderByComparator</code> is specified, then the query will include the given ORDER BY logic. If <code>orderByComparator</code> is absent and pagination is required (<code>start</code> and <code>end</code> are not {@link QueryUtil#ALL_POS}), then the query will include the default ORDER BY logic from {@link FriendlyURLEntryMappingModelImpl}. If both <code>orderByComparator</code> and pagination are absent, for performance reasons, the query will not have an ORDER BY clause and the returned result set will be sorted on by the primary key in an ascending order.
	* </p>
	*
	* @param start the lower bound of the range of friendly url entry mappings
	* @param end the upper bound of the range of friendly url entry mappings (not inclusive)
	* @param orderByComparator the comparator to order the results by (optionally <code>null</code>)
	* @return the ordered range of friendly url entry mappings
	*/
	public java.util.List<FriendlyURLEntryMapping> findAll(int start, int end,
		com.liferay.portal.kernel.util.OrderByComparator<FriendlyURLEntryMapping> orderByComparator);

	/**
	* Returns an ordered range of all the friendly url entry mappings.
	*
	* <p>
	* Useful when paginating results. Returns a maximum of <code>end - start</code> instances. <code>start</code> and <code>end</code> are not primary keys, they are indexes in the result set. Thus, <code>0</code> refers to the first result in the set. Setting both <code>start</code> and <code>end</code> to {@link QueryUtil#ALL_POS} will return the full result set. If <code>orderByComparator</code> is specified, then the query will include the given ORDER BY logic. If <code>orderByComparator</code> is absent and pagination is required (<code>start</code> and <code>end</code> are not {@link QueryUtil#ALL_POS}), then the query will include the default ORDER BY logic from {@link FriendlyURLEntryMappingModelImpl}. If both <code>orderByComparator</code> and pagination are absent, for performance reasons, the query will not have an ORDER BY clause and the returned result set will be sorted on by the primary key in an ascending order.
	* </p>
	*
	* @param start the lower bound of the range of friendly url entry mappings
	* @param end the upper bound of the range of friendly url entry mappings (not inclusive)
	* @param orderByComparator the comparator to order the results by (optionally <code>null</code>)
	* @param retrieveFromCache whether to retrieve from the finder cache
	* @return the ordered range of friendly url entry mappings
	*/
	public java.util.List<FriendlyURLEntryMapping> findAll(int start, int end,
		com.liferay.portal.kernel.util.OrderByComparator<FriendlyURLEntryMapping> orderByComparator,
		boolean retrieveFromCache);

	/**
	* Removes all the friendly url entry mappings from the database.
	*/
	public void removeAll();

	/**
	* Returns the number of friendly url entry mappings.
	*
	* @return the number of friendly url entry mappings
	*/
	public int countAll();
}